@@ -1,6 +1,8 @@
 from sky_api_client.entity.base import Entity
+from sky_api_client.entity.registry import EntityRegistry
 
 
+@EntityRegistry.register('code_table')
 class CodeTable(Entity):
     LIST_URL = '/nxt-data-integration/v1/re/codetables/'
     CREATE_URL = '/nxt-data-integration/v1/re/codetables/'
